import Oid.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/** 
 * Panel that displays a BasisMatroid's properties
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 14 Nov 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class BasisMatroidDisplayPanel extends JPanel
{
  //
  // private data members
  //
  private BasisMatroid mMatroid;
  private JTextArea mTextArea;
  
  /** 
   * constructs a display panel for the passed matroid
   *
   * @param matroid matroid to display
   */
  public BasisMatroidDisplayPanel(BasisMatroid matroid)
  {
    mMatroid = matroid;
    setupPanel(10, 30);
  }

  /**
   * constructs a display panel with the indicated height and width for
   * the passed matroid
   *
   * @param matroid matroid to display
   * @param height height of display
   * @param width width of display
   */
  public BasisMatroidDisplayPanel(BasisMatroid matroid, int height, int width)
  {
    if ((height <= 0) || (width <= 0)) {
      throw new IllegalArgumentException("Invalid height and/or width");
    }
    mMatroid = matroid;
    setupPanel(height, width);
  }

  private void setupPanel(int height, int width) 
  {
    setLayout(new BorderLayout());

    JPanel colPanel = new JPanel();
    colPanel.setLayout(new BoxLayout(colPanel, BoxLayout.Y_AXIS));
    
    JLabel label;
    label = new JLabel("Name: " + mMatroid.getName());
    colPanel.add(label);
    label = new JLabel("Size: " + mMatroid.getSize());
    colPanel.add(label);
    label = new JLabel("Rank: " + mMatroid.getRank());
    colPanel.add(label);
    label = new JLabel("Bases:");
    colPanel.add(label);
    add(colPanel, BorderLayout.NORTH);

    mTextArea = new JTextArea(height, width);
    Font f = mTextArea.getFont();
    mTextArea.setFont(new Font("Monospaced", Font.PLAIN, f.getSize()));
    mTextArea.setEditable(false);
    
    String allBases = new String();
    Vector bases = new Vector(mMatroid.getBases());
    for (Iterator pb = bases.iterator(); pb.hasNext(); ) {
      allBases += ((Subset)pb.next()).toString(true);
      allBases += "\n";
    }
    mTextArea.setText(allBases);
    JScrollPane scrollPane =
      new JScrollPane(mTextArea,
                      JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
                      JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
    add(scrollPane, BorderLayout.CENTER);
  }
}
