package Oid;
import java.io.*;
import java.util.*;

/**
 * BatchChainCalc reads a file with matrices over GF(q) for some prime power
 * q and calculates the circuit and independent set counts of the matroids
 * on each of the matrices.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 28 Dec 2002
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class BatchChainCalc
{
  public static void main(String[] arg)
    throws FileNotFoundException, IOException
  {
    if (arg.length > 0) {
      int r, n;
      int i, m;
      MatrixFileReader rdr;
      FiniteFieldMatroidFormatter fmt = new FiniteFieldMatroidFormatter();
      FiniteFieldMatroid matroid;
      DefaultCircuitAlgorithm cctAlg = new DefaultCircuitAlgorithm();
      DefaultIndependentSetAlgorithm indAlg = 
	new DefaultIndependentSetAlgorithm();
      Vector chain;

      for (rdr = new MatrixFileReader(arg[0]);
	   rdr.hasMoreElements();) {
	matroid = (FiniteFieldMatroid)rdr.nextElement();
	
        System.out.println(fmt.displayMatrix(matroid));
	System.out.println();
	System.out.flush();
	
	r = matroid.getRank();
	n = matroid.getSize();
	m = r+1;
	cctAlg.setInstance(matroid);
	chain = cctAlg.getSubsetCountChain();
	for (i=0; i<=m; i++) {
	  System.out.print(TextAlignment.rightAlign(chain.get(i).toString(),
						    6));
	}
	System.out.println();

	indAlg.setInstance(matroid);
	chain = indAlg.getSubsetCountChain();
	m = r;
	for (i=0; i<=m; i++) {
	  System.out.print(TextAlignment.rightAlign(chain.get(i).toString(),
						    6));
	}
	System.out.println();
	System.out.println();
	System.out.println();

      }
    }
    else {
      System.out.println("Usage: java BatchChainCalc <matroid file>");
    }
  }
}
