package Oid;
import java.util.*;

/**
 * Classes which implement CollectionConstructor generate a collection of 
 * objects from a reference object, with an optional integer parameter.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 4 Oct 2001
 * @version 3.0
 */
public interface CollectionConstructor
{
  /**
   * sets the reference object for this algorithm
   *
   * @param ref reference object
   * @throws IllegalArgumentException if ref isn't of the right type
   */
  public void setInstance(Object ref) 
    throws IllegalArgumentException;

  /**
   * returns the reference object for this algorithm
   *
   * @return reference object for this object 
   */
  public Object getInstance();

  /**
   * indicates whether the algorithm requires a parameter 
   *
   * @return boolean answer
   */
  public boolean requiresParameter();

  /**
   * sets the algorithm's parameter 
   *
   * @param parameter integer parameter for algorithm
   */
  public void setParameter(int parameter);

  /**
   * returns the algorithm's parameter 
   *
   * @return integer parameter for the algorithm
   */
  public int getParameter();

  /**
   * returns the collection of objects contstructed from the reference object 
   *
   * @return generated collection
   */
  public Collection getConstructions();

  /**
   * returns a description of the algorithm used for the construction 
   *
   * @return string with description
   */
  public String getAlgorithmDescription();

  /**
   * returns this algorithm's name
   *
   * @return string with algorithm name 
   */
  public String getName();
}
