package Oid;
import java.util.*;

/**
 * An instance of a class which implements the ComplexityProvider interface 
 * can provide an estimate of the number of steps required to execute any
 * of its methods.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 01 Nov 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public interface ComplexityProvider
{
  /** 
   * returns a value estimating the number of steps required to 
   * execute the method with the passed name, or -1 if the method cannot
   * currently be executed
   *
   * @param methodName name of method to check
   * @return estimate of complexity of method
   */
  public long getComplexityEstimate(String methodName);
  
  /**
   * returns a value estimating the number of steps required to
   * execute the method with the passed name and argument, or -1 if the 
   * method cannot be executed with the passed argument
   *
   * @param methodName name of method to check
   * @param argument single argument to be passed to method
   * @return estimate of complexity of method with this argument
   */
  public long getComplexityEstimate(String methodName, Object argument);

  /**
   * returns a value estimating the number of steps required to 
   * execute the method with the passed name and collection of arguments
   * (which must be placed in correct order for iteration), or -1 if the
   * method cannot be executed with the passed arguments
   *
   * @param methodName name of method to check
   * @param arguments collection of arguments to be passed to method
   * @return estimate of complexity of method with these arguments
   */
  public long getComplexityEstimate(String methodName, Collection arguments);
}
