package Oid;
import java.util.*;

/** 
 * FlatsCalculator was set up to help integrate Padma Gunturi's 
 * lattice and geometric representation display code with Oid.
 *
 * @author Padma Gunturi, Robert J. Kingan, Sandra R. Kingan
 * @date 5 Jun 2002
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class FlatsCalculator
{
  /**
   * evaluates subset containment and catches InvalidSubsetIndexException
   */
  public boolean contains(Subset s, int i)
  {
    boolean answer = false;
    answer = s.get(i);

    return answer;
  }

  /**
   * returns the flats in the form of an array
   */
  public int[] getFlats(Subset s)
  {
    int i,j,n=s.getSize();
    int array[] = new int[n];
	
    j = 0;
    for (i=0; i<n; i++) {
      if (s.get(i)) {
	array[j] = i+1;
	j++;
      }
    }
      
    return array;
  }

  /** 
   * returns the (flats-loops) in the form of an array
   */
  public int[] getFlatsNoLoops(Subset s, Vector loops)
  {
    int i,j,n = s.getSize();
    int array[] = new int[n-loops.size()];
    
    j = 0;
    for (i=0; i<n; i++) {
      if (s.get(i)) {
	if(!loops.contains(new Integer(i+1).toString())) {
	  array[j] = i+1;
	  j++;
	}
      }
    }
      
    return array;
  }
  
  /**
   * returns the (flats-loops-touching edges) in the form of an array
   */
  public int[] getFlatsNoLoopsNoTouchingEdges(Subset s,
					      Vector loops, 
					      Vector touchingElements)
  {
    int i,j,n=s.getSize();
    int array[] = new int[n-loops.size()];
    
    j = 0;
    for (i=0; i<n; i++) {
      if (s.get(i)) {
	
	if(!loops.contains(new Integer(i+1).toString()) 
	   && !touchingElements.contains(new Integer(i+1).toString())) {
	  array[j] = i+1;
	  j++;
	}
      }
    }
  
    return array;
  }
  

}
