package Oid;
import java.util.*;

/**
 * Classes which implement PropertyCalculator determine a property,
 * expressed as an integer, of a reference object, with an optional
 * parameter.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 4 Oct 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public interface PropertyCalculator
{
  /** 
   * sets the reference object for this calculator 
   *
   * @param ref reference to object for this calculator
   * @throws IllegalArgumentException if object isn't of the right type
   */
  public void setInstance(Object ref) 
    throws IllegalArgumentException;

  /** 
   * returns the reference object for this calculator
   *
   * @return reference to object passed to this calculator
   */
  public Object getInstance();

  /** 
   * indicates whether the algorithm requires a parameter
   *
   * @return boolean answer
   */
  public boolean requiresParameter();

  /** 
   * sets the algorithm's parameter
   *
   * @param parameter integer parameter for calculator
   */
  public void setParameter(int parameter);

  /** 
   * returns the algorithm's parameter
   *
   * @return integer parameter for calculator
   */
  public int getParameter();

  /** 
   * returns the property of the reference object
   *
   * @return property calculated for reference object
   */
  public int getProperty();

  /** 
   * returns a description of the algorithm used for the construction
   *
   * @return string with algorithm description
   */
  public String getAlgorithmDescription();

  /** 
   * returns this algorithm's name
   *
   * @return string with algorithm name
   */
  public String getName();

}
