import Oid.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * Subclass of <code>JMenu</code> that also stores a reference 
 * to a <code>Task</code>.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 2 Nov 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class TaskMenu extends JMenu
{
  //
  // private data members
  //
  private Task mTask;

  //
  // constructors 
  //

  /** 
   * Constructs a new instance with no text and the passed
   * <code>Task</code> reference
   *
   * @param t <code>Task</code> to associate with menu
   */
  TaskMenu(Task t)
  {
    mTask = t;
    setText(mTask.getDescription());
  }

  /** 
   * Constructs a new TaskMenu with the supplied string as its text. 
   *
   * @param text text to display on menu
   */
  TaskMenu(String text)
  {
    super(text);
  }

  /** 
   * Constructs a new TaskMenu with the supplied string as its text and with
   * the passed Task reference.
   *
   * @param text text to display on menu
   * @param t <code>Task</code> to associate with menu
   */
  TaskMenu(String text, Task t)
  {
    super(text);
    mTask = t;
  }

  /** 
   * sets the TaskMenu's Task reference 
   *
   * @param t <code>Task</code> to associate with menu
   */
  public void setTask(Task t)
  {
    mTask = t;
  }

  /** 
   * returns the TaskMenu's Task reference 
   *
   * @return <code>Task</code> associated with menu
   */
  public Task getTask()
  {
    return mTask;
  }
}
