import Oid.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * Takes an instance of <code>FiniteFieldMatroid</code> (in standard
 * form) and indicates whether it has any series or parallel elements.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 24 March 2003
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class VisCheckSeriesParallel implements Visualization
{
  /** returns a ReadOnlyTextPanel with the matroid's id matrix */
  public JPanel getVisualization(Object obj)
    throws IllegalArgumentException
  {
    if (!(obj instanceof FiniteFieldMatroid)) {
      throw new IllegalArgumentException("Requires a finite field matroid");
    }

    StringBuffer result = new StringBuffer();

    FiniteFieldMatroid m = (FiniteFieldMatroid)obj;
    FiniteFieldVector[] v;
    int n = m.getSize();
    int r = m.getRank();
    int i;

    if (n <= r) {
      result.append("No series or parallel elements");
    }
    else {
      v = new FiniteFieldVector[n-r];
      for (i=0; i<n-r; i++) {
	v[i] = m.getElement(i+r);
      }
      if (FiniteFieldReduction.hasParallel(v, 0, n-r)) {
	result.append(m.getName() + " has parallel elements\n");
      }
      else {
	result.append(m.getName() + " has no parallel elements\n");
      }

      if (FiniteFieldReduction.hasSeries(v, 0, n-r)) {
	result.append(m.getName() + " has series elements\n");
      }
      else {
	result.append(m.getName() + " has no series elements\n");
      }
    }

    ReadOnlyTextPanel answer = new ReadOnlyTextPanel();
    answer.setText(result.toString());
    return answer;
  }
  
  /** returns the name of this visualization */
  public String getName()
  { 
    return new String("FiniteField matroid series-parallel checker");
  }
  
  public String getDescription()
  { 
    return new String("Takes an instance of FiniteFieldMatroid (in standard form) and indicates whether it has any series or parallel elements.");
  }
}
