import Oid.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * Takes an instance of <code>Matroid</code>, calculates its flats using
 * the class <code>FlatAlgorithm</code>, and displays the flats by rank.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 13 March 2003
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class VisFlats implements Visualization
{
  //
  // private data members
  //
  private Matroid mMatroid;
  private Matroid mDual;

  /** returns a ReadOnlyTextPanel with the matroid's id matrix */
  public JPanel getVisualization(Object obj)
    throws IllegalArgumentException
  {
    if (!(obj instanceof Matroid)) {
      throw new IllegalArgumentException("Requires a matroid");
    }
    mMatroid = (Matroid)obj;

    StringBuffer results = new StringBuffer("Flats\n");
    FlatAlgorithm flatAlg = new FlatAlgorithm();
    Vector allFlats, level;
    Subset flat;
    Iterator pF;
    int rank=mMatroid.getRank(), r;

    flatAlg.setInstance(mMatroid);
    allFlats = flatAlg.getSubsetListVector();
    
    for (r=0; r<=rank; r++) {
      results.append("Rank: " + String.valueOf(r) + "\n");
      level = (Vector)allFlats.get(r);
      for (pF = level.iterator(); pF.hasNext(); ) {
	flat = (Subset)pF.next();
	results.append(flat.toString(true) + "\n");
      }
    }

    ReadOnlyTextPanel answer = new ReadOnlyTextPanel();
    answer.setText(results.toString());
    return answer;
  }
  
  /** returns the name of this visualization */
  public String getName()
  { 
    return new String("Flat calculator");
  }
  
  public String getDescription()
  { 
    return new String("Takes an instance of Matroid and generates its lattice of flats.");
  }
}
