import Oid.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * An <code>VisMatroidFlatMatrix</code> takes an instance of
 * <code>Matroid</code>, and uses it to generate its chain of flats
 * (using the default algorithm). It returns a
 * <code>ReadOnlyTextPanel</code> instance with the chain displayed in
 * table form.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 6 Nov 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class VisMatroidFlatMatrix implements Visualization
{
  //
  // private data members
  //
  private Matroid mMatroid;

  /** returns a ReadOnlyTextPanel with the matrix */
  public JPanel getVisualization(Object obj)
    throws IllegalArgumentException
  {
    if (!(obj instanceof Matroid)) {
      throw new IllegalArgumentException("Requires a matroid");
    }
    mMatroid = (Matroid)obj;

    // set up algorithms
    DefaultFlatAlgorithm flatAlg = new DefaultFlatAlgorithm();

    // get chain
    Vector flatChain;
    try {
      flatAlg.setInstance(mMatroid);
      flatChain = flatAlg.getSubsetCountChain();
    }
    catch (Exception e) {
      // by now, this shouldn't happen
      throw new InternalError(e.toString());
    }

    //
    // build the matrix
    //
    StringBuffer matrix = new StringBuffer();

    int i, j, r = mMatroid.getRank(), n = mMatroid.getSize();
    
    // first row is size values
    matrix.append("Rank        ");
    for (i=0; i<=r; i++) {
      matrix.append(TextAlignment.rightAlign(String.valueOf(i),8));
    }
    matrix.append('\n');

    matrix.append("------------");
    for (i=0; i<=r; i++) {
      matrix.append("--------");
    }
    matrix.append('\n');

    // next flats 
    matrix.append("Flats       ");
    for (i=0; i<=r; i++) {
      j = ((Integer)flatChain.get(i)).intValue();
      matrix.append(TextAlignment.rightAlign(String.valueOf(j),8));
    }
    matrix.append('\n');
    
    ReadOnlyTextPanel answer = new ReadOnlyTextPanel();
    answer.setText(matrix.toString());
    return answer;
  }
  
  /** returns the name of this visualization */
  public String getName()
  { 
    return new String("Matroid flat matrix");
  }
  
  public String getDescription()
  { 
    return new String("An VisMatroidFlatMatrix takes an instance of Matroid, and uses it to generate its chain of flats (using the default algorithm). It returns a ReadOnlyTextPanel instance with this chain displayed in table form.");
  }
}
